==> download-2024.6.21_10.0.53-root-(ip-172-26-12-46).tar.gz: sistema/app/Http/Controllers/Api/apiOt.php <==
<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\user_empresas;
use App\Models\empresas;
use App\Models\categorias;
use App\Models\categorias_empresas;
use App\Models\ciudades;
use App\Models\provincias;
use App\Models\servicios;
use App\Models\direcciones;
use App\Models\comunas;
use App\Models\personas;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use App\Models\tecnicos;
use App\Models\ot_facturadas;
use App\Models\ordenes_trabajos;

use App\Models\clientes;
use App\Models\previsions;
use App\Models\saluds;
use App\Models\tipos_usuarios;



use Carbon\Carbon;



class apiOt extends Controller
{ 
    //
         public  function actualizarDte(request $req){


            $idOtFacturada  = $req->identificadorOt;
            $tipo  = $req->tipo;
            $response  = $req->response;
            

            if(strtoupper($response) == "OK")
            {
                     $ordenes_trabajos =  ordenes_trabajos::where('id', $idOtFacturada)->firstOrFail();

                     if (strtoupper($tipo) == "BOLETA") {
                        $ordenes_trabajos->estado_orden_trabajo_id = 6; //Facturada

                     }elseif(strtoupper($tipo) == "FACTURA") {
                        $ordenes_trabajos->estado_orden_trabajo_id = 6; //Facturada

                     }
                  
                     $ordenes_trabajos->timestamps = false;
                      $ordenes_trabajos->save();

                     //CAMBIAMOS EL ESTADO A LA OTFACTURADA
                     $getDataFacturada = ot_facturadas::where('id_ot_facturada', $idOtFacturada)
                     ->orderBy('id', 'asc')
                     ->firstOrFail();

                     $ot_facturadas =  ot_facturadas::where('id', $getDataFacturada->id)->firstOrFail();
                     //CAMBIAR EL ESTADO DE LA OT
                     $ot_facturadas->estado	  = 0; //actualizada para verla
                     $ot_facturadas->comentario	  = "";
                     $ot_facturadas->timestamps = false;
                     $ot_facturadas->save();

                     

// return  $ordenes_trabajos;

             }elseif (strtoupper($tipo) == "NOTADECREDITO") {
              
              
               $getDataFacturada = ot_facturadas::where('id_ot_facturada', $idOtFacturada)
               ->orderBy('id', 'asc')
               ->firstOrFail();

               
                $ot_facturadas =  ot_facturadas::where('id', $getDataFacturada->id)->firstOrFail();
                //CAMBIAR EL ESTADO DE LA OT
                $ot_facturadas->estado	  = 1; //eliminada
                $ot_facturadas->comentario	  = "Emision de nota de credito";
                $ot_facturadas->timestamps = false;
                $ot_facturadas->save();

               //  return $ot_facturadas;
                //Cambiamos las ot  de las ordenes, la volvemos al estado
                $ordenes_trabajos =  ordenes_trabajos::where('id', $idOtFacturada)->firstOrFail();
                $ordenes_trabajos->estado_orden_trabajo_id = 3; //finalizada

                $ordenes_trabajos->timestamps = false;
                $ordenes_trabajos->save();

            }
             else{

               $getDataFacturada = ot_facturadas::where('id_ot_facturada', $idOtFacturada)
               ->orderBy('id', 'asc')
               ->firstOrFail();

               
                $ot_facturadas =  ot_facturadas::where('id', $getDataFacturada->id)->firstOrFail();
                //CAMBIAR EL ESTADO DE LA OT
                $ot_facturadas->estado	  = 1; //eliminada
                $ot_facturadas->comentario	  = "no se ejecuta correctamente ls emision dte";
                $ot_facturadas->timestamps = false;
                $ot_facturadas->save();

               //  return $ot_facturadas;
                //Cambiamos las ot  de las ordenes, la volvemos al estado
                $ordenes_trabajos =  ordenes_trabajos::where('id', $idOtFacturada)->firstOrFail();
                $ordenes_trabajos->estado_orden_trabajo_id = 3; //finalizada

                $ordenes_trabajos->timestamps = false;
                $ordenes_trabajos->save();

                // $ordenes_trabajos->save();

             }


               

return "OK";
      }
}

==> download-2024.9.2_10.5.12-root-(ip-172-26-12-46).tar.gz: sistema/app/Http/Controllers/Api/apiOt.php <==
<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\user_empresas;
use App\Models\empresas;
use App\Models\categorias;
use App\Models\categorias_empresas;
use App\Models\ciudades;
use App\Models\provincias;
use App\Models\servicios;
use App\Models\direcciones;
use App\Models\comunas;
use App\Models\personas;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use App\Models\tecnicos;
use App\Models\ot_facturadas;
use App\Models\ordenes_trabajos;

use App\Models\clientes;
use App\Models\previsions;
use App\Models\saluds;
use App\Models\tipos_usuarios;



use Carbon\Carbon;



class apiOt extends Controller
{ 
    //
         public  function actualizarDte(request $req){


            $idOtFacturada  = $req->identificadorOt;
            $tipo  = $req->tipo;
            $response  = $req->response;
            $folio  = $req->folio;
  

            if(strtoupper($response) == "OK")
            {
                     $ordenes_trabajos =  ordenes_trabajos::where('id', $idOtFacturada)->firstOrFail();

                     if (strtoupper($tipo) == "BOLETA") {
                        $ordenes_trabajos->estado_orden_trabajo_id = 6; //Facturada

                     }elseif(strtoupper($tipo) == "FACTURA") {
                        $ordenes_trabajos->estado_orden_trabajo_id = 6; //Facturada

                     }
                  
                     $ordenes_trabajos->timestamps = false;
                      $ordenes_trabajos->save();

                     //CAMBIAMOS EL ESTADO A LA OTFACTURADA
                     $getDataFacturada = ot_facturadas::where('id_ot_facturada', $idOtFacturada)
                     ->orderBy('id', 'asc')
                     ->firstOrFail();

                     $ot_facturadas =  ot_facturadas::where('id', $getDataFacturada->id)->firstOrFail();

                     if (strtoupper($tipo) == "BOLETA") {
                        $ot_facturadas->folio_boleta =$folio; //Facturada

                     }elseif(strtoupper($tipo) == "FACTURA") {
                        $ot_facturadas->folio_factura =$folio; //Facturada

                     }
                     //CAMBIAR EL ESTADO DE LA OT
                     $ot_facturadas->estado	  = 0; //actualizada para verla
                     $ot_facturadas->comentario	  = "";
                     $ot_facturadas->timestamps = false;
                     $ot_facturadas->save();

                     

// return  $ordenes_trabajos;

             }elseif (strtoupper($tipo) == "NOTADECREDITO") {
              
              
               $getDataFacturada = ot_facturadas::where('id_ot_facturada', $idOtFacturada)
               ->orderBy('id', 'asc')
               ->firstOrFail();

               
                $ot_facturadas =  ot_facturadas::where('id', $getDataFacturada->id)->firstOrFail();
                //CAMBIAR EL ESTADO DE LA OT
                $ot_facturadas->estado	  = 1; //eliminada
                $ot_facturadas->folio_notacredito	  = $folio; //eliminada

                $ot_facturadas->comentario	  = "Emision de nota de credito";
                $ot_facturadas->timestamps = false;
                $ot_facturadas->save();

               //  return $ot_facturadas;
                //Cambiamos las ot  de las ordenes, la volvemos al estado
                $ordenes_trabajos =  ordenes_trabajos::where('id', $idOtFacturada)->firstOrFail();
                $ordenes_trabajos->estado_orden_trabajo_id = 3; //finalizada

                $ordenes_trabajos->timestamps = false;
                $ordenes_trabajos->save();

            }
             else{

               $getDataFacturada = ot_facturadas::where('id_ot_facturada', $idOtFacturada)
               ->orderBy('id', 'asc')
               ->firstOrFail();

               
                $ot_facturadas =  ot_facturadas::where('id', $getDataFacturada->id)->firstOrFail();
                //CAMBIAR EL ESTADO DE LA OT
                $ot_facturadas->estado	  = 1; //eliminada
                $ot_facturadas->comentario	  = "no se ejecuta correctamente ls emision dte";
                $ot_facturadas->timestamps = false;
                $ot_facturadas->save();

               //  return $ot_facturadas;
                //Cambiamos las ot  de las ordenes, la volvemos al estado
                $ordenes_trabajos =  ordenes_trabajos::where('id', $idOtFacturada)->firstOrFail();
                $ordenes_trabajos->estado_orden_trabajo_id = 3; //finalizada

                $ordenes_trabajos->timestamps = false;
                $ordenes_trabajos->save();

                // $ordenes_trabajos->save();

             }


               

return "OK";
      }
}
